@@ -30,9 +30,6 @@ def seas_line_plot(df, fwd=None, title=None, yaxis_title=None, inc_change_sum=Tr
     if histfreq.startswith('W'):
         text = seas.index.strftime('%d-%b')
 
-    if title is None:
-        title = ''
-
     fig = go.Figure()
 
     if shaded_range is not None:
@@ -160,6 +157,8 @@ def reindex_year_line_plot(df, title=None, yaxis_title=None, inc_change_sum=True
     return fig
 
 
+# TODO remove once transitioned over legacy code
+# Moved to commodplotutil
 def plhtml(fig, margin=cpu.narrow_margin, **kwargs):
     """
     Given a plotly figure, return it as a div
@@ -173,3 +172,5 @@ def plhtml(fig, margin=cpu.narrow_margin, **kwargs):
         return pl.plot(fig, include_plotlyjs=False, output_type='div')
 
     return ''
+
+
