@@ -1,4 +1,6 @@
 import pandas as pd
+import plotly.graph_objects as go
+import plotly.offline as pl
 from commodutil import dates
 default_line_col = 'khaki'
 
@@ -168,3 +170,29 @@ def reindex_year_df_rel_col(df):
     return res_col
 
 
+def plhtml(fig, margin=narrow_margin, **kwargs):
+    """
+    Given a plotly figure, return it as a div
+    """
+    # if 'margin' in kwargs:
+    if fig is not None:
+        fig.update_layout(margin=margin)
+
+        fig.update_xaxes(automargin=True)
+        fig.update_yaxes(automargin=True)
+        return pl.plot(fig, include_plotlyjs=False, output_type='div')
+
+    return ''
+
+
+def convert_dict_plotly_fig_html_div(d):
+    """
+    Given a dict (that might be passed to jinja), convert all plotly figures of html divs
+    """
+    for k, v in d.items():
+        if isinstance(d[k], go.Figure):
+            d[k] = plhtml(d[k])
+        if isinstance(d[k], dict):
+            convert_dict_plotly_fig_html_div(d[k])
+
+    return d
\ No newline at end of file
